<?php
/*
Plugin Name: SmoothGallery
Plugin URI: http://www.christianschenk.org/projects/wordpress-smoothgallery-plugin/
Description: Embed JonDesign's SmoothGallery into your posts and pages.
Version: 1.1
Author: Christian Schenk
Author URI: http://www.christianschenk.org/
*/

#
# WordPress SmoothGallery plugin
# Copyright (C) 2008 Christian Schenk
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

# Identifier for various actions of this script (e.g. css)
define('SMOOTHGALLERY_ACTION', 'smoothgallery_action');
# the CSS file
define('SMOOTHGALLERY_CSS_FILE', dirname(__FILE__).'/css/jd.gallery.css');
# path to this plugin
define('SMOOTHGALLERY_URL', '/wp-content/plugins/smoothgallery');


/**
 * Helper methods
 */
class SmoothGalleryHelper {

	/**
	 * Returns the contents of a file as a string.
	 */
	function getFileContents($filename) {
		$handle = fopen ($filename, "rb");
		$contents = fread ($handle, filesize ($filename));
		fclose ($handle);
		return $contents;
	}

}


/**
 * Parses the actions
 */
if (!empty($_REQUEST[SMOOTHGALLERY_ACTION])) {
	switch ($_REQUEST[SMOOTHGALLERY_ACTION]) {
		case 'css':
			header('Content-type: text/css');
			$css = SmoothGalleryHelper::getFileContents(SMOOTHGALLERY_CSS_FILE);
			$css = str_replace('<HEIGHT>', $_REQUEST['height'], $css);
			$css = str_replace('<WIDTH>', $_REQUEST['width'], $css);
			$css = str_replace('<URL>', $_REQUEST['prefix'].SMOOTHGALLERY_URL, $css);
			echo $css;
			# fall through
		default:
			die();
			break;
	}
}


/**
 * Returns the parameters for the gallery if they're attached to a post or a
 * page, otherwise it will return default values.
 */
function get_smoothgallery_parameters() {
	global $post;
	if (! isset($post)) return null;

	# default values
	$rVal = array('height' => 345,
	              'width' => 460);

	# get values from the post's metadata
	$meta = get_post_meta($post->ID, 'smoothgallery', true);
	if (empty($meta)) return null;
	$meta = strtolower($meta);
	if ($meta != '1' and $meta != 'on') {
		#if (preg_match('/^h:(.*)$/i', $meta, $matches)) {
		#	$rVal['height'] = $matches[1];
		#}
		##$rVal['width'] = $meta[1];
		if (($param = get_smoothgallery_parameter($meta, 'h')) !== false) $rVal['height'] = $param;
		if (($param = get_smoothgallery_parameter($meta, 'w')) !== false) $rVal['width'] = $param;
	}

	return $rVal;
}

/**
 * Returns the value from a string in the following format:
 * '<$param><delimiter><value> [...]'
 * where delimiter will be either ':' or '='.
 *
 * @param string $meta the string with the data
 * @param string $param the parameter we're searching for
 * @return mixed the value from the string, otherwise false
 */
function get_smoothgallery_parameter($meta, $param) {
	if (preg_match('/'.$param.'[:=]{1}(.*)/i', $meta, $matches)) {
		return rtrim($matches[1]);
	}
	return false;
}

/**
 * Adds a link to the css stylesheet in the header.
 */
function add_smoothgallery_css() {
	$parameters = get_smoothgallery_parameters();
	if (empty($parameters)) return;

	$height = $parameters['height'];
	$width = $parameters['width'];
	$url = get_bloginfo('wpurl').SMOOTHGALLERY_URL.'/smoothgallery.php';
	echo '<link rel="stylesheet" type="text/css" href="'.$url.'?'.SMOOTHGALLERY_ACTION.'=css&amp;prefix='.urlencode(get_bloginfo('wpurl')).'&amp;height='.$height.'&amp;width='.$width.'" />';
}
if (function_exists('add_action')) add_action('wp_head', 'add_smoothgallery_css');


/**
 * This will add the JavaScript to the footer.
 * TODO: we want to be able to customize the gallery
 */
function add_smoothgallery_js() {
	$parameters = get_smoothgallery_parameters();
	if (empty($parameters)) return;

	$url = get_bloginfo('wpurl').SMOOTHGALLERY_URL;
	?>

<script src="<?php echo $url; ?>/scripts/mootools.namespaced.js" type="text/javascript"></script>
<script src="<?php echo $url; ?>/scripts/jd.gallery.namespaced.js" type="text/javascript"></script>
<script type="text/javascript">
function startGallery() { var myGallery = new gallery($('myGallery'), { timed: false, showArrows: true, showCarousel: false, embedLinks: true }); }
window.addEvent('domready', startGallery);
</script> 

	<?php
}
if (function_exists('add_action')) add_action('wp_footer', 'add_smoothgallery_js');

?>
